unit uDropMasterTarget;

{ Example application for Raize DropMaster.

  Demonstrates various techniques in the use of TDMGraphicTarget
  with a TImage and a TImageEnView.

  The dropped picture is assigned to TImageEnView in the DMGraphicTarget2Drop
  event:
  ImageEnView1.Bitmap.Assign(ThePicture.Bitmap);
  ImageEnView1.Update;

  The main point here: see how little code is needed.  Most of the code here
  was written by Delphi!  And the portion that was manually coded is mainly
  for user-interface purposes. }

interface

uses
  Windows, Types, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, Buttons, Grids, ExtCtrls, DMComps, hyieutils, iexBitmaps,
  hyiedefs, iesettings, iexLayers, iexRulers, ieview, imageenview;

type
  TForm1 = class(TForm)
    Panel2: TPanel;
    DMGraphicTarget1: TDMGraphicTarget;
    btnClose: TButton;
    CheckBox6: TCheckBox;
    CheckBox7: TCheckBox;
    CheckBox8: TCheckBox;
    Label25: TLabel;
    Label30: TLabel;
    Label1: TLabel;
    Panel5: TPanel;
    ScrollBox1: TScrollBox;
    Image1: TImage;
    RadioGroup2: TRadioGroup;
    Panel1: TPanel;
    ImageEnView1: TImageEnView;
    DMGraphicTarget2: TDMGraphicTarget;
    Button1: TButton;
    Label2: TLabel;
    procedure btnCloseClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure DMGraphicTarget1Drop(Sender: TObject; Acceptor: TWinControl;
      thePicture: TPicture; X, Y: Integer);
    procedure CheckBox6Click(Sender: TObject);
    procedure RadioGroup2Click(Sender: TObject);
    procedure CheckBox7Click(Sender: TObject);
    procedure DMGraphicTarget2Drop(Sender: TObject; Acceptor: TWinControl;
      ThePicture: TPicture; X, Y: Integer);
    procedure Button1Click(Sender: TObject);
  private
    { Private declarations }
    saveAcceptGraphicFormats: TDropGraphicFormats;
    procedure UpdateAcceptGraphicFormats;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

uses
  TypInfo;

procedure TForm1.btnCloseClick(Sender: TObject);
// Close down
begin
  Close;
end;

procedure TForm1.FormCreate(Sender: TObject);
// Set up at form creation time
begin
  saveAcceptGraphicFormats := DMGraphicTarget1.AcceptGraphicFormats;
  // Set various controls in the correct state
  RadioGroup2.itemIndex := integer(DMGraphicTarget1.PreferredFormat);
  with DMGraphicTarget1 do
  begin
    // Is the preferred format the only one?
    CheckBox7.Checked := [PreferredFormat] = AcceptGraphicFormats;
  end;
end;

procedure TForm1.DMGraphicTarget1Drop(Sender: TObject;
  Acceptor: TWinControl; thePicture: TPicture; X, Y: Integer);
var
  aString: string;
begin
  if Assigned(thePicture) then
  begin
    // Give the picture to the TImage.  The following 2 lines are equivalent.
    // image1.picture := (Sender as TDMGraphicTarget).Picture;
    Image1.Picture := thePicture;
    // Optionally stretch depending on checkbox.
    Image1.Stretch := CheckBox6.Checked;
    // Show in the label what kind of object got dropped
    //aString := Image1.picture.graphic.ClassName;
    //Delete(aString, 1, 1);  // Drop the leading "T"
    // Following is an alternative for the preceding 2 lines
    case (Sender as TDMGraphicTarget).DroppedGraphicFormat of
      dgfBitmap: aString := 'Bitmap';
      dgfMetafile: aString := 'Metafile';
    else
      aString := '???'; // Should never happen!
    end;
    Label1.Caption := 'Dropped a ' + aString;
  end;
end;

procedure TForm1.DMGraphicTarget2Drop(Sender: TObject; Acceptor: TWinControl;
  ThePicture: TPicture; X, Y: Integer);
var
  aString: string;
begin
  if Assigned(ThePicture) then
  begin
    // Give the picture to the TImageEnView.
    ImageEnView1.Bitmap.Assign(ThePicture.Bitmap);
    ImageEnView1.Update;
    // Optionally stretch depending on checkbox.
    if CheckBox6.Checked then
      ImageEnView1.Fit;
    // Show in the label what kind of object got dropped
    //aString := Image1.picture.graphic.ClassName;
    //Delete(aString, 1, 1);  // Drop the leading "T"
    // Following is an alternative for the preceding 2 lines
    case (Sender as TDMGraphicTarget).DroppedGraphicFormat of
      dgfBitmap: aString := 'Bitmap';
      dgfMetafile: aString := 'Metafile';
    else
      aString := '???'; // Should never happen!
    end;
    Label1.Caption := 'Dropped a '+ aString;
  end;
end;

procedure TForm1.Button1Click(Sender: TObject);
begin
  Image1.Picture := nil;
  ImageEnView1.ClearAll;
  ImageEnView1.Update;
  Label1.Caption := '';
end;

procedure TForm1.CheckBox6Click(Sender: TObject);
begin
  with Image1 do
  begin
    // If the image is empty, don't do anything
    if not ((Picture.Width=0) and (Picture.Height=0)) then
    begin
      Stretch := CheckBox6.Checked; // Are we stretching?
      // Image1.AutoSize and ScrollBox1.AutoScroll need to match
      AutoSize := not Stretch;
      ScrollBox1.AutoScroll := not Stretch;
      if Stretch then
      begin
        // Stretching, so reset the image to match the scrollbox bounds
        SetBounds(ScrollBox1.left, ScrollBox1.Top, ScrollBox1.Width, ScrollBox1.Height);
      end;
    end;
  end;
  if CheckBox6.Checked then
    ImageEnView1.Fit()
  else
    ImageEnView1.Zoom := 100;
end;

procedure TForm1.RadioGroup2Click(Sender: TObject);
begin
  // Choose a new preferred format
  DMGraphicTarget1.PreferredFormat := TDropGraphicFormat(RadioGroup2.itemIndex);
  // And make sure the acceptible formats are updated as a result
  UpdateAcceptGraphicFormats;
end;

procedure TForm1.UpdateAcceptGraphicFormats;
// After a change in the preferred format, or in whether the preferred format
// alone is acceptable, update the acceptable formats.
begin
  with DMGraphicTarget1 do
  begin
    if CheckBox7.Checked then
      // Preferred only - i.e., use the preferred one if it intersects with the
      // design-time acceptable graphic formats (set intersection)
      AcceptGraphicFormats := [PreferredFormat]*saveAcceptGraphicFormats
    else
      // Not preferred only - take the design-time defaults
      AcceptGraphicFormats := saveAcceptGraphicFormats;
  end;
end;

procedure TForm1.CheckBox7Click(Sender: TObject);
begin
  UpdateAcceptGraphicFormats;
end;

end.
